@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2019  The Software Heritage developers
+# Copyright (C) 2017-2020  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -10,10 +10,15 @@ import textwrap
 from django.http import HttpResponse
 from django.shortcuts import render
 from django.template.defaultfilters import filesizeformat
-from django.utils.html import escape
 from django.utils.safestring import mark_safe
 
-from swh.model.identifiers import persistent_identifier
+from swh.model.identifiers import (
+    persistent_identifier,
+    CONTENT,
+    DIRECTORY,
+    REVISION,
+    SNAPSHOT,
+)
 from swh.web.browse.browseurls import browse_route
 from swh.web.browse.snapshot_context import get_snapshot_context
 from swh.web.browse.utils import (
@@ -28,12 +33,13 @@ from swh.web.browse.utils import (
     content_display_max_size,
     gen_snapshot_link,
     get_readme_to_display,
-    get_swh_persistent_ids,
     format_log_entries,
     gen_person_mail_link,
 )
 from swh.web.common import service
 from swh.web.common.exc import NotFoundExc, handle_view_exception
+from swh.web.common.identifiers import get_swhids_info
+from swh.web.common.typing import RevisionMetadata, SWHObjectInfo
 from swh.web.common.utils import (
     reverse,
     format_utc_iso_date,
@@ -44,13 +50,10 @@ from swh.web.common.utils import (
 
 def _gen_content_url(revision, query_string, path, snapshot_context):
     if snapshot_context:
-        url_args = snapshot_context["url_args"]
-        url_args["path"] = path
         query_params = snapshot_context["query_params"]
+        query_params["path"] = path
         query_params["revision"] = revision["id"]
-        content_url = reverse(
-            "browse-origin-content", url_args=url_args, query_params=query_params
-        )
+        content_url = reverse("browse-origin-content", query_params=query_params)
     else:
         content_path = "%s/%s" % (revision["directory"], path)
         content_url = reverse(
@@ -284,18 +287,17 @@ def revision_log_browse(request, sha1_git):
             "snapshot_context": None,
             "vault_cooking": None,
             "show_actions_menu": True,
-            "swh_ids": None,
+            "swhids_info": None,
         },
     )
 
 
 @browse_route(
     r"revision/(?P<sha1_git>[0-9a-f]+)/",
-    r"revision/(?P<sha1_git>[0-9a-f]+)/(?P<extra_path>.+)/",
     view_name="browse-revision",
     checksum_args=["sha1_git"],
 )
-def revision_browse(request, sha1_git, extra_path=None):
+def revision_browse(request, sha1_git):
     """
     Django view that produces an HTML display of a revision
     identified by its id.
@@ -315,7 +317,7 @@ def revision_browse(request, sha1_git, extra_path=None):
         path = request.GET.get("path", None)
         dir_id = None
         dirs, files = None, None
-        content_data = None
+        content_data = {}
         if origin_url:
             try:
                 snapshot_context = get_snapshot_context(
@@ -355,50 +357,37 @@ def revision_browse(request, sha1_git, extra_path=None):
     except Exception as exc:
         return handle_view_exception(request, exc)
 
-    revision_data = {}
-
-    revision_data["author"] = "None"
-    if revision["author"]:
-        author_link = gen_person_mail_link(revision["author"])
-        revision_data["author"] = author_link
-    revision_data["committer"] = "None"
-    if revision["committer"]:
-        committer_link = gen_person_mail_link(revision["committer"])
-        revision_data["committer"] = committer_link
-    revision_data["committer date"] = format_utc_iso_date(revision["committer_date"])
-    revision_data["date"] = format_utc_iso_date(revision["date"])
-    revision_data["directory"] = revision["directory"]
-    if snapshot_context:
-        revision_data["snapshot"] = snapshot_id
-        browse_snapshot_link = gen_snapshot_link(snapshot_id)
-        revision_data["context-independent snapshot"] = browse_snapshot_link
-
-    revision_data["context-independent directory"] = gen_directory_link(
-        revision["directory"]
-    )
-    revision_data["revision"] = sha1_git
-    revision_data["merge"] = revision["merge"]
-    revision_data["metadata"] = escape(
-        json.dumps(
+    revision_metadata = RevisionMetadata(
+        object_type=REVISION,
+        object_id=sha1_git,
+        revision=sha1_git,
+        revision_url=gen_revision_link(sha1_git),
+        author=revision["author"]["fullname"] if revision["author"] else "None",
+        author_url=gen_person_mail_link(revision["author"])
+        if revision["author"]
+        else "None",
+        committer=revision["committer"]["fullname"]
+        if revision["committer"]
+        else "None",
+        committer_url=gen_person_mail_link(revision["committer"])
+        if revision["committer"]
+        else "None",
+        committer_date=format_utc_iso_date(revision["committer_date"]),
+        date=format_utc_iso_date(revision["date"]),
+        directory=revision["directory"],
+        directory_url=gen_directory_link(revision["directory"]),
+        merge=revision["merge"],
+        metadata=json.dumps(
             revision["metadata"], sort_keys=True, indent=4, separators=(",", ": ")
-        )
+        ),
+        parents=revision["parents"],
+        synthetic=revision["synthetic"],
+        type=revision["type"],
+        snapshot=snapshot_id,
+        snapshot_url=gen_snapshot_link(snapshot_id) if snapshot_id else None,
+        origin_url=origin_url,
     )
 
-    if origin_info:
-        revision_data["origin url"] = gen_link(origin_info["url"], origin_info["url"])
-        revision_data["context-independent revision"] = gen_revision_link(sha1_git)
-
-    parents = ""
-    for p in revision["parents"]:
-        parent_link = gen_revision_link(
-            p, link_text=None, link_attrs=None, snapshot_context=snapshot_context
-        )
-        parents += parent_link + "<br/>"
-
-    revision_data["parents"] = mark_safe(parents)
-    revision_data["synthetic"] = revision["synthetic"]
-    revision_data["type"] = revision["type"]
-
     message_lines = ["None"]
     if revision["message"]:
         message_lines = revision["message"].split("\n")
@@ -412,7 +401,7 @@ def revision_browse(request, sha1_git, extra_path=None):
 
     query_params = {
         "snapshot_id": snapshot_id,
-        "origin": origin_url,
+        "origin_url": origin_url,
         "timestamp": timestamp,
         "visit_id": visit_id,
     }
@@ -448,10 +437,11 @@ def revision_browse(request, sha1_git, extra_path=None):
         "revision_id": sha1_git,
     }
 
-    swh_objects = [{"type": "revision", "id": sha1_git}]
+    swh_objects = [SWHObjectInfo(object_type=REVISION, object_id=sha1_git)]
 
     content = None
     content_size = None
+    filename = None
     mimetype = None
     language = None
     readme_name = None
@@ -462,6 +452,9 @@ def revision_browse(request, sha1_git, extra_path=None):
     error_message = ""
     error_description = ""
 
+    extra_context = dict(revision_metadata)
+    extra_context["path"] = f"/{path}" if path else "/"
+
     if content_data:
         breadcrumbs[-1]["url"] = None
         content_size = content_data["length"]
@@ -476,8 +469,8 @@ def revision_browse(request, sha1_git, extra_path=None):
         query_params = {}
         if path:
             filename = path_info[-1]["name"]
-            query_params["filename"] = path_info[-1]["name"]
-            revision_data["filename"] = filename
+            query_params["filename"] = filename
+            extra_context["filename"] = filename
 
         top_right_link = {
             "url": reverse(
@@ -489,7 +482,9 @@ def revision_browse(request, sha1_git, extra_path=None):
             "text": "Raw File",
         }
 
-        swh_objects.append({"type": "content", "id": file_info["target"]})
+        swh_objects.append(
+            SWHObjectInfo(object_type=CONTENT, object_id=file_info["target"])
+        )
 
         error_code = content_data["error_code"]
         error_message = content_data["error_message"]
@@ -530,22 +525,22 @@ def revision_browse(request, sha1_git, extra_path=None):
         vault_cooking["directory_context"] = True
         vault_cooking["directory_id"] = dir_id
 
-        swh_objects.append({"type": "directory", "id": dir_id})
+        swh_objects.append(SWHObjectInfo(object_type=DIRECTORY, object_id=dir_id))
 
     diff_revision_url = reverse(
         "diff-revision",
         url_args={"sha1_git": sha1_git},
         query_params={
-            "origin": origin_url,
+            "origin_url": origin_url,
             "timestamp": timestamp,
             "visit_id": visit_id,
         },
     )
 
     if snapshot_id:
-        swh_objects.append({"type": "snapshot", "id": snapshot_id})
+        swh_objects.append(SWHObjectInfo(object_type=SNAPSHOT, object_id=snapshot_id))
 
-    swh_ids = get_swh_persistent_ids(swh_objects, snapshot_context)
+    swhids_info = get_swhids_info(swh_objects, snapshot_context, extra_context)
 
     heading = "Revision - %s - %s" % (
         sha1_git[:7],
@@ -562,9 +557,9 @@ def revision_browse(request, sha1_git, extra_path=None):
         "browse/revision.html",
         {
             "heading": heading,
-            "swh_object_id": swh_ids[0]["swh_id"],
+            "swh_object_id": swhids_info[0]["swhid"],
             "swh_object_name": "Revision",
-            "swh_object_metadata": revision_data,
+            "swh_object_metadata": revision_metadata,
             "message_header": message_lines[0],
             "message_body": "\n".join(message_lines[1:]),
             "parents": parents,
@@ -574,6 +569,8 @@ def revision_browse(request, sha1_git, extra_path=None):
             "content": content,
             "content_size": content_size,
             "max_content_size": content_display_max_size,
+            "filename": filename,
+            "encoding": content_data.get("encoding"),
             "mimetype": mimetype,
             "language": language,
             "readme_name": readme_name,
@@ -584,7 +581,7 @@ def revision_browse(request, sha1_git, extra_path=None):
             "vault_cooking": vault_cooking,
             "diff_revision_url": diff_revision_url,
             "show_actions_menu": True,
-            "swh_ids": swh_ids,
+            "swhids_info": swhids_info,
             "error_code": error_code,
             "error_message": error_message,
             "error_description": error_description,
