@@ -3,10 +3,13 @@
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
+import textwrap
+
 from django.utils.html import escape
 
 from hypothesis import given
 
+from swh.model.identifiers import CONTENT, DIRECTORY
 from swh.web.browse.utils import (
     get_mimetype_and_encoding_for_content,
     prepare_content_for_display,
@@ -25,6 +28,7 @@ from swh.web.tests.strategies import (
     content_text_non_utf8,
     content_text_no_highlight,
     content_image_type,
+    content_unsupported_image_type_rendering,
     content_text,
     invalid_sha1,
     unknown_content,
@@ -57,10 +61,22 @@ def test_content_view_text(client, archive_data, content):
         assert_contains(resp, escape(content_display["content_data"]))
     assert_contains(resp, url_raw)
 
-    swh_cnt_id = get_swh_persistent_id("content", sha1_git)
+    swh_cnt_id = get_swh_persistent_id(CONTENT, sha1_git)
     swh_cnt_id_url = reverse("browse-swh-id", url_args={"swh_id": swh_cnt_id})
     assert_contains(resp, swh_cnt_id)
     assert_contains(resp, swh_cnt_id_url)
+    assert_contains(
+        resp,
+        textwrap.indent(
+            (
+                f"Browse archived content\n"
+                f'<a href="{swh_cnt_id_url}">\n'
+                f"  {swh_cnt_id}\n"
+                f"</a>"
+            ),
+            " " * 4,
+        ),
+    )
 
 
 @given(content_text_no_highlight())
@@ -82,7 +98,7 @@ def test_content_view_text_no_highlight(client, archive_data, content):
     assert_contains(resp, escape(content_display["content_data"]))
     assert_contains(resp, url_raw)
 
-    swh_cnt_id = get_swh_persistent_id("content", sha1_git)
+    swh_cnt_id = get_swh_persistent_id(CONTENT, sha1_git)
     swh_cnt_id_url = reverse("browse-swh-id", url_args={"swh_id": swh_cnt_id})
 
     assert_contains(resp, swh_cnt_id)
@@ -101,7 +117,7 @@ def test_content_view_no_utf8_text(client, archive_data, content):
 
     assert resp.status_code == 200
     assert_template_used(resp, "browse/content.html")
-    swh_cnt_id = get_swh_persistent_id("content", sha1_git)
+    swh_cnt_id = get_swh_persistent_id(CONTENT, sha1_git)
     swh_cnt_id_url = reverse("browse-swh-id", url_args={"swh_id": swh_cnt_id})
     assert_contains(resp, swh_cnt_id_url)
     assert_contains(resp, escape(content_display["content_data"]))
@@ -125,6 +141,26 @@ def test_content_view_image(client, archive_data, content):
     assert_contains(resp, url_raw)
 
 
+@given(content_unsupported_image_type_rendering())
+def test_content_view_image_no_rendering(client, archive_data, content):
+    url = reverse("browse-content", url_args={"query_string": content["sha1"]})
+
+    resp = client.get(url)
+
+    mimetype = content["mimetype"]
+    encoding = content["encoding"]
+
+    assert resp.status_code == 200
+    assert_template_used(resp, "browse/content.html")
+    assert_contains(
+        resp,
+        (
+            f"Content with mime type {mimetype} and encoding {encoding} "
+            "cannot be displayed."
+        ),
+    )
+
+
 @given(content_text())
 def test_content_view_text_with_path(client, archive_data, content):
     path = content["path"]
@@ -155,6 +191,18 @@ def test_content_view_text_with_path(client, archive_data, content):
     filename = split_path[-1]
     path = path.replace(root_dir_sha1 + "/", "").replace(filename, "")
 
+    swhid_context = {
+        "anchor": get_swh_persistent_id(DIRECTORY, root_dir_sha1),
+        "path": f"/{path}{filename}",
+    }
+
+    swh_cnt_id = get_swh_persistent_id(
+        CONTENT, content["sha1_git"], metadata=swhid_context
+    )
+    swh_cnt_id_url = reverse("browse-swh-id", url_args={"swh_id": swh_cnt_id})
+    assert_contains(resp, swh_cnt_id)
+    assert_contains(resp, swh_cnt_id_url)
+
     path_info = gen_path_info(path)
 
     root_dir_url = reverse("browse-directory", url_args={"sha1_git": root_dir_sha1})
@@ -167,7 +215,9 @@ def test_content_view_text_with_path(client, archive_data, content):
 
     for p in path_info:
         dir_url = reverse(
-            "browse-directory", url_args={"sha1_git": root_dir_sha1, "path": p["path"]}
+            "browse-directory",
+            url_args={"sha1_git": root_dir_sha1},
+            query_params={"path": p["path"]},
         )
         assert_contains(resp, '<a href="' + dir_url + '">' + p["name"] + "</a>")
 
